==> fungi_bot-0.1.0.tar.gz: fungi_bot-0.1.0/README.md <==

<h1 align="center">
    Fungi 🍄
</h1>

<p align="center">
    <img alt="A campsite showing mushrooms having a nice time." src="https://github.com/hyerland/Fungi/blob/main/docs/public/fungi-introduction-1.png?raw=true">
    <img alt="GitHub License" src="https://img.shields.io/github/license/hyerland/fungi?style=flat-square&logo=github&logoSize=auto&label=License&labelColor=black&color=pink">
    <img alt="Netlify" src="https://img.shields.io/netlify/5fc5dd0f-f77c-4372-8ff3-4bde662d6ba7?style=flat-square&logo=netlify&logoColor=white&logoSize=auto&label=Netlify&labelColor=black&color=pink">
    <img alt="PyPI - Version" src="https://img.shields.io/pypi/v/fungi-bot?style=flat-square&logo=pypi&logoColor=white&logoSize=auto&label=Version&labelColor=black&color=pink">
</p>

Self-hosted discord bot with an extensive configuration file to fit any servers need, all for free.

- 💻 Extensive configuration
  - 80% of fungi can be configurable to fit any server's needs. From anime servers to reading clubs, fungi can surely find a place.
- 🔨 100% Free, and Open Source
  - Being able to be open source means every single feature and configuration is free and open to you to edit. No hidden traps. 🎈

> Visit the documentation website for a more pleasing viewing experience: [https://fungibot.netlify.app](https://fungibot.netlify.app)

## So... What is exactly Fungi? 🤔

Fungi is a solution of sorts to many bots having advanced customization (name, branding, etc.) locked behind **premium subscriptions, purchases, or any other form of monetization** which sucks to **you,** the user simply trying to set up a nice discord server.

This is where Fungi comes in. Fungi was designed to be...

- Modular 🧩
- Easy to use 🚀
- Customizable 💻
- and Free, and Open Source 🔨

## Installation 📦

> Python 3.8 or greater is required

Fungi can easily be installed from PyPi by running:

```bash
pip install fungi-bot
```

This would install the **latest stable** version of Fungi to your python installation.

### Using Fungi

Using fungi can be done by doing the following within a terminal.

```bash
fungi start
```

#### Creating an application

> If you already have an application and token, you can skip this step.

In order to continue, head to [discord.com/developers](https://discord.com/developers) to create an application.

- After creating an application, go to the "Bot" tab and generate and copy the token.
  - Never post or share your token with anyone. It's a major security risk and could let to your account getting hacked by bad actors.
- Here is where you can customize the profile of the bot which isn't required but makes your bot nice to use.

> Fungi or Fungi Framework doesn't store any information about your application in servers, fungi only works on your local machine with your configuration.

This will start the **FTS (First Time Setup)** of the Fungi Framework with only asking vital information such as, **token, name, prefix, and to have debug mode enabled.**

By default, Fungi will store the configuration with the current working directory for instance, if you run `fungi start` in `C:/Users/Example/Documents` then the configuration will be stored in `C:/Users/Example/Documents/fungi.json` for later use and reference.

Once your configuration file is created, the bot will automatically start after FTS and will be ready to use. *See the [Configuration guide](https://fungibot.netlify.app/config/#configuration-%F0%9F%94%A8) for more information.*

## People of Fungi 🍄

People of fungi (contributors, translators, etc.) are important as they shaped the project for new improvements and helped make Fungi possible. In fact, they're so important that they're all here!

### Contributors

Fungi wouldn't be possible without the help of all of the people who have contributed to the project. Here is a list of all of the people who have made Fungi possible in major ways.

- Adam Garza (Hyerland)
  - Creator | Lead developer of the project.
- hiivemiind
  - Graphic Designer | Created all graphics shown within the project.

> Find them here for their related links and more: [https://fungibot.netlify.app/community/#contributors](https://fungibot.netlify.app/community/#contributors)

Fungi wouldn't also be possible without contributions from the community on github.

<a href="https://github.com/hyerland/Fungi/graphs/contributors">
  <img alt="Contributors on GitHub." src="https://contrib.rocks/image?repo=hyerland/Fungi" />
</a>

==> fungi_bot-0.1.1.tar.gz: fungi_bot-0.1.1/README.md <==

<h1 align="center">
    Fungi 🍄
</h1>

<p align="center">
    <img alt="A campsite showing mushrooms having a nice time." src="https://github.com/hyerland/Fungi/blob/main/docs/public/fungi-introduction-1.png?raw=true">
    <img alt="GitHub License" src="https://img.shields.io/github/license/hyerland/fungi?style=flat-square&logo=github&logoSize=auto&label=License&labelColor=black&color=pink">
    <img alt="Netlify" src="https://img.shields.io/netlify/5fc5dd0f-f77c-4372-8ff3-4bde662d6ba7?style=flat-square&logo=netlify&logoColor=white&logoSize=auto&label=Netlify&labelColor=black&color=pink">
    <img alt="PyPI - Version" src="https://img.shields.io/pypi/v/fungi-bot?style=flat-square&logo=pypi&logoColor=white&logoSize=auto&label=Version&labelColor=black&color=pink">
</p>

Self-hosted discord bot with an extensive configuration file to fit any servers need, all for free.

- 💻 Extensive configuration
  - 80% of fungi can be configurable to fit any server's needs. From anime servers to reading clubs, fungi can surely find a place.
- 🔨 100% Free, and Open Source
  - Being able to be open source means every single feature and configuration is free and open to you to edit. No hidden traps. 🎈
- ✨ Early Development
  - Fungi is being actively developed and improved from features to bug fixes and improvements in which came from your support and voices.

> Visit the documentation website for a more pleasing viewing experience: [https://fungibot.netlify.app](https://fungibot.netlify.app)

## So... What is exactly Fungi? 🤔

Fungi is a solution of sorts to many bots having advanced customization (name, branding, etc.) locked behind **premium subscriptions, purchases, or any other form of monetization** which sucks to **you,** the user simply trying to set up a nice discord server.

This is where Fungi comes in. Fungi was designed to be...

- Modular 🧩
- Easy to use 🚀
- Customizable 💻
- and Free, and Open Source 🔨

## Installation 📦

> Python 3.8 or greater is required

Fungi can easily be installed from PyPi by running:

```bash
pip install fungi-bot
```

This would install the **latest stable** version of Fungi to your python installation.

### Using Fungi

Using fungi can be done by doing the following within a terminal.

```bash
fungi start
```

#### Creating an application

> If you already have an application and token, you can skip this step.

In order to continue, head to [discord.com/developers](https://discord.com/developers) to create an application.

- After creating an application, go to the "Bot" tab and generate and copy the token.
  - Never post or share your token with anyone. It's a major security risk and could let to your account getting hacked by bad actors.
- Here is where you can customize the profile of the bot which isn't required but makes your bot nice to use.

> Fungi or Fungi Framework doesn't store any information about your application in servers, fungi only works on your local machine with your configuration.

This will start the **FTS (First Time Setup)** of the Fungi Framework with only asking vital information such as, **token, name, prefix, and to have debug mode enabled.**

By default, Fungi will store the configuration with the current working directory for instance, if you run `fungi start` in `C:/Users/Example/Documents` then the configuration will be stored in `C:/Users/Example/Documents/fungi.json` for later use and reference.

Once your configuration file is created, the bot will automatically start after FTS and will be ready to use. *See the [Configuration guide](https://fungibot.netlify.app/config/#configuration-%F0%9F%94%A8) for more information.*

## People of Fungi 🍄

People of fungi (contributors, translators, etc.) are important as they shaped the project for new improvements and helped make Fungi possible. In fact, they're so important that they're all here!

### Contributors

Fungi wouldn't be possible without the help of all of the people who have contributed to the project. Here is a list of all of the people who have made Fungi possible in major ways.

- Adam Garza (Hyerland)
  - Creator | Lead developer of the project.
- hiivemiind
  - Graphic Designer | Created all graphics shown within the project.

> Find them here for their related links and more: [https://fungibot.netlify.app/developers/#contributors](https://fungibot.netlify.app/developers/#contributors)

Fungi wouldn't also be possible without contributions from the community on github.

<a href="https://github.com/hyerland/Fungi/graphs/contributors">
  <img alt="Contributors on GitHub." src="https://contrib.rocks/image?repo=hyerland/Fungi" />
</a>
